CovControlOgk
containing the control parameters for CovOgkCovControlOgk(niter = 2, beta = 0.9, mrob = NULL, vrob = rrcov:::.vrobGK, smrob = "scaleTau2", svrob = "gk")tau scale defined in
Yohai and Zamar (1998), see scaleTau2.
The C version covGK(). The C versscaleTau2 - the scale tau function defined in Yohai and Zamar (1998)gk,
the one proposed by Gnanadesikan and Kettenring (1972)CovControlOgk objectsmrob and svrob
(i.e. the names of the functions as strings), a native code written in C will be called which
is by far faster than the R version.
If the arguments mrob and vrob are not NULL, the specified functions
will be used via the pure R implementation of the algorithm. This could be quite slow.## the following two statements are equivalent
ctrl1 <- new("CovControlOgk", beta=0.95)
ctrl2 <- CovControlOgk(beta=0.95)
data(hbk)
CovOgk(hbk, control=ctrl1)Run the code above in your browser using DataLab