Objects from the Class
Objects can be created by calls of the form new("Linda", ...) but the
usual way of creating Linda objects is a call to the function
Linda which serves as a constructor.Extends
Class "LdaRobust", directly.
Class "Lda", by class "LdaRobust", distance 2.Methods
No methods defined with class "Linda" in the signature.