Usage
PcaLocantore(x, ...)
## S3 method for class 'default':
PcaLocantore(x, k = 0, kmax = ncol(x), delta = 0.001,
na.action = na.fail, scale = FALSE, signflip = TRUE, trace=FALSE, ...)
## S3 method for class 'formula':
PcaLocantore(formula, data = NULL, subset, na.action, \dots)Arguments
formula
a formula with no response variable, referring only to
numeric variables.
data
an optional data frame (or similar: see
model.frame) containing the variables in the
formula formula. subset
an optional vector used to select rows (observations) of the
data matrix x.
na.action
a function which indicates what should happen
when the data contain NAs. The default is set by
the na.action setting of options, and is
...
arguments passed to or from other methods.
x
a numeric matrix (or data frame) which provides
the data for the principal components analysis.
k
number of principal components to compute. If k is missing,
or k = 0, the algorithm itself will determine the number of
components by finding such k that $l_k/l_1 >= 10.E-3$ and
$\Sigma_{j=1}^k l_j/
kmax
maximal number of principal components to compute.
Default is kmax=10. If k is provided, kmax
does not need to be specified, unless k is larger than 10.
delta
an accuracy parameter
scale
a logical value indicating whether the variables should be
scaled to have unit variance (only possible if there are no constant
variables). As a scale function mad is used but alternatively, a vector of length equal
the number of
signflip
a logical value indicating wheather to try to solve the sign indeterminancy of the loadings -
ad hoc approach setting the maximum element in a singular vector to be positive. Default is signflip = FALSE
trace
whether to print intermediate results. Default is trace = FALSE