covMest(x, cor=FALSE, r = 0.45, arp = 0.05, eps=1e-3,
maxiter=120, control, t0, S0)cor = FALSE(n - p)/(2 * n) and 1 and the default is 0.450.05.1e-3"mest" which is basically a list with
the following components. This class is "derived" from "mcd" so that
the same generic functions - print, plot, summary - can
be used.
NOTE: this is going to change - in one of the next revisions covMest
will return an S4 class "mest" which is derived (i.e. contains)
form class "cov".cor = TRUE).match.call).rho(d)
with the median under normality. This is then not an S-estimate, but is
instead a constrained M-estimate. In order to make the smooth estimators
to work, a reasonable starting point is necessary, which will lead reliably to a
good solution of the estimator. In covMest the MCD computed by
covMcd is used, but the user has the possibility to give her own
initial estimates.covMcddata(hbk)
hbk.x <- data.matrix(hbk[, 1:3])
covMest(hbk.x)
## the following three statements are equivalent
c0 <- covMest(hbk.x)
c1 <- covMest(hbk.x, r = 0.45)
c2 <- covMest(hbk.x, control = rrcov.control(r = 0.45))
## direct specification overrides control one:
c3 <- covMest(hbk.x, r = 0.45,
control = rrcov.control(r=0.25))
c1Run the code above in your browser using DataLab