myscreeplotPlots screeplots for two covariance matricesmtxconfusionComputes a confusion matrix between actual and predicted class membershipsqrtmReturns the square root of a symetric positive definite matrixonesReturns a nxp matrix filled with oneszerosReturns a nxp matrix filled with zerosvecnormReturns the norm of a vectorrankMMReturns the rank of the matrixrepmatReplicates a matrixmyscreeplot(rcov, ccov)
mtxconfusion(actual, predicted, prior = NULL, printit=FALSE)
sqrtm(A)
rankMM(A, tol = NULL, sv = svd(A, 0, 0)$d)
ones(n=1, p=1)
zeros(n=1, p=1)
repmat(A, n, p)