summary method for class "lts".## S3 method for class 'lts':
summary(object, correlation = FALSE, \dots)
## S3 method for class 'summary.lts':
print(x, digits = max(3, getOption("digits") - 3), ...)"lts", usually, a result of a call to ltsReg."summary.lts", usually, a result of a call to summary.lts.TRUE, the correlation matrix of the estimated parameters is returned and printed.summary.lts computes and returns a list of summary
statistics of the fitted linear model given in object, using
the components of this object (list elements).y containing the residuals from the weighted
least squares regression.residuals[i].cov.unscaled, if correlation = TRUE is specified.summary(object)$correlation directly.summarydata(brain)
summary(ltsReg(brain~body, data = log(brain)))Run the code above in your browser using DataLab