summary.mcd: Summary Method for MCD objects
Description
summary method for class "mcd".Usage
## S3 method for class 'mcd':
summary(object, digits = max(3, getOption("digits") - 3), ...)Arguments
object
an object of class "mcd", usually, a result of a call to covMcd. digits
the number of significant digits to use when printing.
...
further arguments passed to or from other methods.
Value
- The
mcd object is returned.
Details
This function prints summary statistics for the weighted covariance matrix
and location estimates with weights based on MCD estimates.
While the function print.mcd prints only the robust estimates of
the location and the covariance matrix, summary.mcd will print also the
correlation matrix (if requested in the call to covMcd with cor=TRUE),
the eigenvalues of the covariance or the correlation matrix and the robust distances.Examples
Run this codedata(brain)
summary(covMcd(log(brain)))
Run the code above in your browser using DataLab