Usage
CovControlSde(nsamp = 0, maxres = 0, tune = 0.95, eps = 0.5, prob = 0.99,
seed = NULL, trace = FALSE, tolSolve = 1e-14)Arguments
nsamp
a positive integer giving the number of resamples required;
nsamp may not be reached if too many of the p-subsamples,
chosen out of the observed vectors, are in a hyperplane.
If nsamp = 0 all possible
maxres
a positive integer specifying the maximum number of
resamples to be performed including those that are discarded due to linearly
dependent subsamples. If maxres is omitted it will be set to 2 times nsamp.
tune
a numeric value between 0 and 1 giving the fraction of the data to receive non-zero weight.
Defaults to 0.95.
prob
a numeric value between 0 and 1 specifying the probability of high breakdown point;
used to compute nsamp when nsamp is omitted. Defaults to 0.99.
eps
a numeric value between 0 and 0.5 specifying the breakdown point;
used to compute nsamp when nresamp is omitted. Defaults to 0.5.
seed
starting value for random generator. Default is seed = NULL.
trace
whether to print intermediate results. Default is trace = FALSE.
tolSolve
numeric tolerance to be used for inversion
(solve) of the covariance matrix in
mahalanobis.