Usage
PcaHubert(x, ...)
## S3 method for class 'default':
PcaHubert(x, k = 0, kmax = 10, alpha = 0.75, mcd = TRUE, trace=FALSE, \dots)
## S3 method for class 'formula':
PcaHubert(formula, data = NULL, subset, na.action, \dots)
Arguments
formula
a formula with no response variable, referring only to
numeric variables.
data
an optional data frame (or similar: see
model.frame) containing the variables in the
formula formula. subset
an optional vector used to select rows (observations) of the
data matrix x.
na.action
a function which indicates what should happen
when the data contain NAs. The default is set by
the na.action setting of options, and is
...
arguments passed to or from other methods.
x
a numeric matrix (or data frame) which provides
the data for the principal components analysis.
k
number of principal components to compute. If k is missing,
or k = 0, the algorithm itself will determine the number of
components by finding such k that $l_k/l_1 >= 10.E-3$ and
$\Sigma_{j=1}^k l_j/
kmax
maximal number of principal components to compute.
Default is kmax=10. If k is provided, kmax
does not need to be specified, unless k is larger than 10.
alpha
this parameter measures the fraction of outliers the algorithm should
resist. In MCD alpha controls the size of the subsets over which the
determinant is minimized, i.e. alpha*n observations are used for
computing the determinant. Allowed
mcd
Logical - when the number of variables is sufficiently small,
the loadings are computed as the eigenvectors of the MCD covariance matrix,
hence the function CovMcd() is automatically called. The n trace
whether to print intermediate results. Default is trace = FALSE